# -*- Mode: rpm-spec -*-
#
# First: Get versions names right is complicated (tm)
# Second: kernel allways have the version & release number in the name
#         this is done to preserving a working kernel when you install 
#         a new one
# Stored in %rpmrversion & %rpmrelease
#
# We want to reflect in the kernel naming:
#   - kernel in with is based (ex. 2.6.0) 
#     this version is stored in %realversion
#   - Number of Mandrake kernel based on this vanilla kernel (ex. 1mdk).
#     stored in %mdkrelease.
#    
# That gives us a nice name: 2.6.0.1mdk
# 
# As version and release are allways fixed, name of the package is 
# going to be:
#        kernel-2.6.0.1mdk-1-1mdk
#
# Confused already?
#
# Now there arrive pre/rc kernels.  This kernels have the particularity
# that they have the name of the new kernel, but they are based in the
# tar file of the old kernel, i.e. names are basically:
#  - kernel: 2.6.0
#  - patch name: 2.6.0-pre3
#    stored in %use_patch
#  - Number of Mandrake kernel based in this pre kernel 2mdk
#
# That gives us a nice name again: 2.6.0.pre3.2mdk
# Problems now are:
#   - sublevel of kernel 0 (needed for tar file)
#   - sublevel of kernel is 1 (needed for prepatch and naming 
#     the package).
# This explains the need of %tar_version, because this will be different
# of %real_version if there is a pre/rc patch.
# 
# Still with me?
# 
# There are still a problem, when real 2.4.22 cames out, it will have
# a mane like: 
#              2.4.22.1mdk
# this name is (for rpm ordering of versions) smaller than:
#              2.4.22.pre3.2mdk
# to fix that we add a 0 to the name (and appear the need of realrelease)
# in the pre/rc
# 	       2.4.22.0.pre3.2mdk
#
# Take one aspirine.  Relax.
#
# Problem now is that names are just really ugly, and specially
# lilo/grub names are very difficult to read/type.
# Notice that the extra .0 is there only to make visual comparations 
# easy, but it is an annoyance.
#
# Lilo name for this kernel will be:
#       2422-0.pre3.2mdk
# And as everybody knows, putting dot's in lilo names is not nice.
# Then we change the kernel name (for loaders, and directory names only)
# to a more userfriendly:
# 		2.4.22pre3-2mdk
# That way, smp, enterprise versions continue to have the well known names
# in the loader of:
#		2422pre3-2smp
#
# For a non pre/rc kernel define (real examples in brakets)
#       2.6.X.Ymdk [2.6.0.2mdk]
# where
#	%sublvel = X 	[0]
#   	%mdkrelease = Y [2]
#	%use_patch 0	[0]
#
# For a pre/rc kernel do:
#	2.6.X.0.Y.Zmdk [2.6.3.0.pre3.2mdk]
# where
#	%sublvel = X 	[3]
#   	%mdkrelease = Z [2]
#	%use_patch Y	[pre3]
#
# I hope this is all clear now. If you have any doubt, please mail me at:
#
# Juan Quintela <quintela@mandrakesoft.com>

%define sublevel 7
%define mdkrelease 1
%define use_patch 0

# This is only to make life easier for people that creates derivated kernels
# a.k.a name it kernel-tmb :)
%define kname  kernel-sds
%define tmbver 31

# Define Mandrake Linux version we are building for
%define mdkversion %(perl -pe '/(\\d+)\\.(\\d)\\.?(\\d)?/; $_="$1$2".($3||0)' /etc/mandrake-release)

%define build_club 1
%define build_club_all 0
%{?_with_cluball: %global build_club_all 1}

%define build_uponly 0
%{?_with_uponly: %global build_uponly 1}

# multimedia kernel
%define build_multimedia 1
%{?_with_multimedia: %global build_multimedia 1}
%{?_without_multimedia: %global build_multimedia 0}

%define preload_realcap 0
%if %{build_multimedia}
%{?_with_realcap: %global preload_realcap 1}
%endif

# and more of my hacks
%if %build_club
%define preload_my_mods	1
%endif

%define my_modules mousedev psmouse pcspkr


# smaller build time , ? may be for kernel-laptop ?
# do not build build scsi lowlevel drivers
# by default scsi lowlevel drivers are built
%define skip_scsi_mods 0
%{?_without_scsidrv: %global skip_scsi_mods 1}

%define skip_libata_mods 0
%{?_without_libatadrv: %global skip_libata_mods 1}

# planet ccrma dri low latency patches
%define build_drill 0
%{?_with_drill: %global build_drill 1}

# turn nfs support to built in, not module
# to support root on nfs 
%define builtin_nfs 0
%{?_with_nfs: %global builtin_nfs 1}

# disable apic
%define build_noapic 0
%{?_without_apic: %global build_noapic 1}
%{?_with_noapic: %global build_noapic 1}

# You shouldn't have to change any kernel/patch/version number
# for 2.6 kernels

# When we are using a pre/rc patch, the tarball is a sublevel -1
%if %use_patch
%define tar_version 2.6.%(expr %{sublevel} - 1)
%define patchversion %{use_patch}q%{mdkrelease}.sds%{tmbver}
%define realrelease 0.%{use_patch}.%{mdkrelease}.sds.%{tmbver}mdk
%else
%define tar_version 2.6.%{sublevel}
%define patchversion q%{mdkrelease}.sds%{tmbver}
%define realrelease %{mdkrelease}.sds.%{tmbver}mdk
%endif

# never touch the folowing two fields
%define rpmversion 1
%define rpmrelease 1mdk
%define realversion 2.6.%{sublevel}
%define mdkversion %{realversion}-%{realrelease}
%define patches_ver 2.6.%{sublevel}-%{patchversion}

# having different top level names for packges means
# that you have to remove them by hard :(
%define top_dir_name %{kname}

%define build_dir ${RPM_BUILD_DIR}/%top_dir_name
%define src_dir %{build_dir}/linux-%tar_version
%define KVERREL %{realversion}-%{realrelease}

# this is the config that contains all the drivers for the hardware/
# things that I use (Juan Quintela).
%define build_minimal 0
%define build_acpi 1

%define build_kheaders 0
%define build_debug 0
%define build_doc 0
%define build_source 1

%define build_101 %(if [ `awk '{print $3}' /etc/mandrake-release` = 10.1 ];then echo 1; else echo 0; fi)
%define build_100 %(if [ `awk '{print $4}' /etc/mandrake-release` = 10.0 ];then echo 1; else echo 0; fi)
%define build_92 %(if [ `awk '{print $4}' /etc/mandrake-release` = 9.2 ];then echo 1; else echo 0; fi)

%define build_up 1
%ifarch alpha sparc sparc64 x86_64
%define build_smp 1
%else
%define build_smp 0
%endif

%ifarch alpha x86_64 ia64 sparc sparc64
%define build_enterprise 0
%else
%define build_enterprise 1
%endif

%ifarch alpha sparc sparc64
%define build_BOOT 1
%else
%define build_BOOT 0
%endif

%ifarch %{ix86} x86_64
%define build_secure 0
%else
%define build_secure 0
%endif

%ifarch %{ix86}
%define build_i686_up_4GB 1
%define build_p3_smp_64GB 0
%else
%define build_i686_up_4GB 0
%define build_p3_smp_64GB 0
%endif

%if %{build_club_all}
%ifarch %{ix86} x86_64
%define build_secure	1
%endif
%define build_smp	1
%endif

%define build_uponly 0 
%{?_with_uponly: %global build_uponly 1}
%if %{build_uponly}
%define build_smp 0
%define build_enterprise 0
%define build_secure 0
%define build_source 0
%define build_p3_smp_64GB 0
%define build_i686_up_4GB 0
%endif

%define build_upsource 0 
%{?_with_upsource: %global build_upsource 1}
%if %{build_upsource}
%define build_smp 0
%define build_enterprise 0
%define build_secure 0
%define build_source 1
%define build_p3_smp_64GB 0
%define build_i686_up_4GB 0
%endif


# Win4Lin builds
%define build_win4lin 0
%{?_with_win4lin: %global build_win4lin 1}
%if %build_win4lin
%define kname kernel-sds-w4l
%endif

# swsusp2 specific builds

# seems swsusp2 is broken with gcc-3.4 in cooker
# disable it by default

%define build_swsusp2 0
%{?_with_swsusp2: %global build_swsusp2 1}
%{?_without_swsusp2: %global build_swsusp2 0}

%if 1 
%if %build_swsusp2 
%define kname kernel-swsusp2
%endif
%endif

# ruby specific builds
%define build_ruby 0
%{?_with_ruby: %global build_ruby 1}
%if %build_ruby 
%define kname kernel-ruby
%endif


# End of user definitions
%{?_without_up: %global build_up 0}
%{?_without_smp: %global build_smp 0}
%{?_without_secure: %global build_secure 0}
%{?_without_enterprise: %global build_enterprise 0}
%{?_without_BOOT: %global build_BOOT 0}
%{?_without_i686up4GB: %global build_i686_up_4GB 0}
%{?_without_p3smp64GB: %global build_p3_smp_64GB 0}
%{?_without_minimal: %global build_minimal 0}
%{?_without_debug: %global build_debug 0}
%{?_without_doc: %global build_doc 0}
%{?_without_source: %global build_source 0}

%{?_with_up: %global build_up 1}
%{?_with_smp: %global build_smp 1}
%{?_with_secure: %global build_secure 1}
%{?_with_enterprise: %global build_enterprise 1}
%{?_with_BOOT: %global build_BOOT 1}
%{?_with_i686up4GB: %global build_i686_up_4GB 1}
%{?_with_p3smp64GB: %global build_p3_smp_64GB 1}
%{?_with_minimal: %global build_minimal 1}
%{?_with_debug: %global build_debug 1}
%{?_with_acpi: %global build_acpi 1}
%{?_with_doc: %global build_doc 1}
%{?_with_source: %global build_source 1}

%{?_with_kheaders: %global build_kheaders 1}
%{?_with_92: %global build_92 1}
%{?_with_100: %global build_100 1}

%define build_nosrc 0
%{?_with_nosrc: %global build_nosrc 1}

%define kmake %make
# there are places where parallel make don't work
%define smake make

# Aliases for amd64 builds (better make source links?)
%define target_cpu	%(echo %{_target_cpu} | sed -e "s/amd64/x86_64/")
%define target_arch	%(echo %{_arch} | sed -e "s/amd64/x86_64/")

Summary: The Linux kernel (the core of the Linux operating system).
Name: %{kname}-%{mdkversion}
Version: %{rpmversion}
Release: %{rpmrelease}
License: GPL
Group: System/Kernel and hardware
ExclusiveArch: %{ix86} alpha ppc ppc64 x86_64 amd64 sparc sparc64
ExclusiveOS: Linux
URL: http://www.kernel.org/

####################################################################
#
# Sources
#
### This is for full SRC RPM
Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-%{tar_version}.tar.bz2
### This is for stripped SRC RPM
%if %build_nosrc
NoSource: 0
%endif
Source1: linux-%{tar_version}.tar.bz2.info

Source4: README.kernel-sources
Source5: README.Mandrakelinux

Source15: tmb-linux-mdkconfig.h
Source16: linux-merge-config.awk

Source100: linux-%{patches_ver}.tar.bz2

####################################################################
#
# Patches

#
# Patch0 to Patch100 are for core kernel upgrades.
#

# Pre linus patch: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/testing

%if %use_patch
Patch1: patch-%realversion-%use_patch.bz2
%endif

# Win4Lin patches
Patch100: Kernel-Win4Lin3-2.6.7.patch.bz2
Patch101: mki-adapter26_1_3_6.patch.bz2
Patch102: Win4Lin_configs.patch.bz2

# planet ccrma dri low latency hacks, 
# might be severely broken on some hardware
Patch200: low-latency-mga-2.6.4.patch.bz2
Patch201: low-latency-r128-2.6.4.patch.bz2
Patch202: low-latency-radeon-2.6.4.patch.bz2

####################################################################

# Defines for the things that are needed for all the kernels
%define requires1 modutils >= 2.4.26-3mdk
%define requires2 mkinitrd >= 3.5.18-4mdk
%define requires3 bootloader-utils >= 1.6-7mdk
%define requires4 sysfsutils >= 0.4.0-1mdk module-init-tools >= 3.0-1mdk

%define kprovides kernel = %{realversion}, alsa

BuildRoot: %{_tmppath}/%{name}-%{realversion}-build
Provides: module-info, %kprovides
Autoreqprov: no
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4
BuildRequires: gcc >= 3.3.2-6mdk module-init-tools >= 3.0-1mdk

%description
The kernel package contains the Linux kernel (vmlinuz), the core of your
Mandrakelinux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

For instructions for update, see:
http://www.mandrakesecure.net/en/kernelupdate.php

  !! The sds kernels is an experimental kernel based on the mdk kernels,
     with added patches. Some of them may/will never end up in the main 
     mdk kernels due to their experimental nature. Some refer to this
     kernel as a 'hackkernel' ...
     Use these kernels at your own risk !!


#
# kernel-smp: Symmetric MultiProcessing kernel
#

%package -n %{kname}-smp-%{mdkversion}
Summary: The Linux Kernel compiled for SMP machines.
Group: System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-smp-%{mdkversion}
This package includes a SMP version of the Linux %{realversion} kernel. It is
required only on machines with two or more CPUs, although it should work
fine on single-CPU boxes.

For instructions for update, see:
http://www.mandrakesecure.net/en/kernelupdate.php

  !! The sds kernels is an experimental kernel based on the mdk kernels,
     with added patches. Some of them may/will never end up in the main 
     mdk kernels due to their experimental nature. Some refer to this
     kernel as a 'hackkernel' ...
     Use these kernels at your own risk !!


%package -n %{kname}-secure-%{mdkversion}
Summary: The Linux Kernel compiled for SECURE machines.
Group: System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-secure-%{mdkversion}
This package includes a SECURE version of the Linux %{realversion}
kernel. This package add options for kernel that make it more secure
for servers and such. See :

http://www.nsa.gov/selinux/

for list of features we have included.

For instructions for update, see:
http://www.mandrakesecure.net/en/kernelupdate.php

  !! The sds kernels is an experimental kernel based on the mdk kernels,
     with added patches. Some of them may/will never end up in the main 
     mdk kernels due to their experimental nature. Some refer to this
     kernel as a 'hackkernel' ...
     Use these kernels at your own risk !!


#
# kernel-enterprise: Symmetric MultiProcessing kernel
#

%package -n %{kname}-enterprise-%{mdkversion}
Summary: The Linux Kernel compiled with options for Enterprise server usage.
Group: System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-enterprise-%{mdkversion}
This package includes a kernel that has appropriate configuration options
enabled for the typical large enterprise server.  This includes SMP support
for multiple processor machines, support for large memory configurations
and other appropriate items.

For instructions for update, see:
http://www.mandrakesecure.net/en/kernelupdate.php

  !! The sds kernels is an experimental kernel based on the mdk kernels,
     with added patches. Some of them may/will never end up in the main 
     mdk kernels due to their experimental nature. Some refer to this
     kernel as a 'hackkernel' ...
     Use these kernels at your own risk !!


#
# kernel-boot: BOOT Kernel
#

%package -n %{kname}-BOOT-%{mdkversion}
Summary: The version of the Linux kernel used on installation boot disks.
Group: System/Kernel and hardware
Url: https://kenobi.mandrakesoft.com/~chmou/kernel/BOOT/

%description -n %{kname}-BOOT-%{mdkversion}
This package includes a trimmed down version of the Linux kernel.
This kernel is used on the installation boot disks only and should not
be used for an installed system, as many features in this kernel are
turned off because of the size constraints.

For instructions for update, see:
http://www.mandrakesecure.net/en/kernelupdate.php

  !! The sds kernels is an experimental kernel based on the mdk kernels,
     with added patches. Some of them may/will never end up in the main 
     mdk kernels due to their experimental nature. Some refer to this
     kernel as a 'hackkernel' ...
     Use these kernels at your own risk !!


%package -n %{kname}-i686-up-4GB-%{mdkversion}
Summary: The Linux Kernel compiled for i686 with 4GB.
Group: System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-i686-up-4GB-%{mdkversion}
This package includes a kernel that has appropriate configuration options
enabled for the typical desktop with more than 1GB of memory.

For instructions for update, see:
http://www.mandrakesecure.net/en/kernelupdate.php

  !! The sds kernels is an experimental kernel based on the mdk kernels,
     with added patches. Some of them may/will never end up in the main 
     mdk kernels due to their experimental nature. Some refer to this
     kernel as a 'hackkernel' ...
     Use these kernels at your own risk !!


%package -n %{kname}-p3-smp-64GB-%{mdkversion}
Summary: The Linux Kernel compiled with options for pentium III, smp and 64GB memory.
Group: System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-p3-smp-64GB-%{mdkversion}
This package includes a kernel that has appropriate configuration options
enabled for the typical large enterprise server.  This includes SMP support
for multiple processor machines, support for large memory configurations (64GB)
and support for pentium III.

For instructions for update, see:
http://www.mandrakesecure.net/en/kernelupdate.php

  !! The sds kernels is an experimental kernel based on the mdk kernels,
     with added patches. Some of them may/will never end up in the main 
     mdk kernels due to their experimental nature. Some refer to this
     kernel as a 'hackkernel' ...
     Use these kernels at your own risk !!


%package -n %{kname}-source
Version: %{realversion}
Release: %{realrelease}
Requires: glibc-devel, ncurses-devel, make, gcc, perl
Summary: The source code for the Linux kernel.
Group: Development/Kernel
Autoreqprov: no
Provides: kernel-source

%description -n %{kname}-source
The kernel-source package contains the source code files for the Linux
kernel. These source files are needed to build most C programs, since
they depend on the constants defined in the source code. The source
files can also be used to build a custom kernel that is better tuned to
your particular hardware, if you are so inclined (and you know what you're
doing).

  !! The sds kernels is an experimental kernel based on the mdk kernels,
     with added patches. Some of them may/will never end up in the main 
     mdk kernels due to their experimental nature. Some refer to this
     kernel as a 'hackkernel' ...
     Use these kernels at your own risk !!


#
# kernel-doc: documentation for the Linux kernel
#
%package -n %{kname}-doc
Version: %{version}
Release: %{release}
Summary: Various documentation bits found in the kernel source.
Group: Books/Computer books

%description -n %{kname}-doc
This package contains documentation files form the kernel source. Various
bits of information about the Linux kernel and the device drivers shipped
with it are documented in these files. You also might want install this
package if you need a reference to the options that can be passed to Linux
kernel modules at load time.

  !! The tmb kernels is an experimental kernel based on the mdk kernels,
     with added patches. Some of them may/will never end up in the main 
     mdk kernels due to their experimental nature. Some refer to this
     kernel as a 'hackkernel' ...
     Use these kernels at your own risk !!


#
# End packages - here begins build stage
#
%prep
%setup -q -n %top_dir_name -c

%setup -q -n %top_dir_name -D -T -a100

%define patches_dir ../%{patches_ver}/

cd %src_dir
%if %use_patch
%patch1 -p1
%endif


%if %{build_swsusp2}
%{patches_dir}/scripts/apply_patches --patch_dir=%{build_dir}/%{patches_ver}/swsusp2/
%else
%if %{build_ruby}
%{patches_dir}/scripts/apply_patches --patch_dir=%{build_dir}/%{patches_ver}/ruby/
%else
%{patches_dir}/scripts/apply_patches
%endif # ruby
%endif # swsusp2

#Keep Win4Lin patches separate from the patches tarball
%if %build_win4lin
# win4lin
#patch100 -p1
# mki_adapter
#patch101 -p1

# Adding configs for win4lin
(cd %{patches_dir}
#patch102 -p1
)
%endif

%if %build_drill
%patch200 -p1
%patch201 -p1
%patch202 -p1
%endif

# PATCH END
#
# Setup Begin
#

# Prepare all the variables for calling create configs

%if %build_debug
%define debug --debug
%else
%define debug --no-debug
%endif

%if %build_acpi
%define acpi --acpi
%else
%define acpi --no-acpi
%endif

%if %build_minimal
%define minimal --minimal
%else
%define minimal --no-minimal
%endif

%if %build_multimedia
%define multimedia --multimedia
%else
%define multimedia --no-multimedia
%endif

# ? omit some modules, for one or other reason 
%if %{skip_scsi_mods}
perl -pi -e 's!CONFIG_SCSI_LOW_LEVEL=y!# CONFIG_SCSI_LOW_LEVEL is not set!' \
	%{patches_dir}/configs/*.config
%else
perl -pi -e 's!# CONFIG_SCSI_LOW_LEVEL is not set!CONFIG_SCSI_LOW_LEVEL=y!' \
	%{patches_dir}/configs/*.config
%endif

%if %{skip_libata_mods}
perl -pi -e 's!CONFIG_SCSI_SATA=y!# CONFIG_SCSI_SATA is not set!' \
	%{patches_dir}/configs/*.config
%else
perl -pi -e 's!# CONFIG_SCSI_SATA is not set!CONFIG_SCSI_SATA=y!' \
	%{patches_dir}/configs/*.config
%endif

%if %{build_101}
perl -pi -e 's!CONFIG_ACER_HK=m!# CONFIG_ACER_HK is not set!' \
	%{patches_dir}/configs/*.config
%else
perl -pi -e 's!# CONFIG_ACER_HK is not set!CONFIG_ACER_HK=m!' \
	%{patches_dir}/configs/*.config
%endif

%if ! %{build_win4lin}
perl -pi -e 's!CONFIG_MKI=y!# CONFIG_MKI is not set!' \
	%{patches_dir}/configs/*.config
%else
perl -pi -e 's!# CONFIG_MKI is not set!CONFIG_MKI=y!' \
	%{patches_dir}/configs/*.config
%endif

%if %{builtin_nfs}
perl -pi -e 's!CONFIG_NFS_FS=m!CONFIG_NFS_FS=y!' \
	%{patches_dir}/configs/*.config
%else
perl -pi -e 's!CONFIG_NFS_FS=y!CONFIG_NFS_FS=m!' \
	%{patches_dir}/configs/*.config
%endif


%{patches_dir}/scripts/create_configs %debug %acpi %minimal  %multimedia --user_cpu="%{target_cpu}"


# make sure the kernel has the sublevel we know it has...
LC_ALL=C perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile

# get rid of unwanted files
find . -name '*~' -o -name '*.orig' -o -name '*.append' |xargs rm -f

%if %build_kheaders

kheaders_dirs=`echo $PWD/include/{asm-*,linux,sound}`

pushd %build_dir
install -d kernel-headers/
cp -a $kheaders_dirs kernel-headers/
tar cf kernel-headers-%mdkversion.tar kernel-headers/
bzip2 -9f kernel-headers-%mdkversion.tar
rm -rf kernel-headers/
# build_kheaders
%endif


%build
# Common target directories
%define _kerneldir /usr/src/linux-%{KVERREL}
%define _bootdir /boot
%define _modulesdir /lib/modules
%define _savedheaders ../../savedheaders/

# Directories definition needed for building
%define temp_root %{build_dir}/temp-root
%define temp_source %{temp_root}%{_kerneldir}
%define temp_boot %{temp_root}%{_bootdir}
%define temp_modules %{temp_root}%{_modulesdir}

PrepareKernel() {
	name=$1
	extension=$2
	echo "Make dep for kernel $extension"
	%smake -s mrproper

	# We can't use only defconfig anyore because we have the autoconf patch,

	if [ -z "$name" ]; then
		config_name="defconfig"
	else
		config_name="defconfig-$name"
	fi
# workaround for sparc64 kernels
	if [ %{target_cpu} == "sparc64" ]; then
		cp arch/%{target_cpu}/$config_name .config
	else
		cp arch/%{target_arch}/$config_name .config
	fi
%if %{build_noapic}
perl -pi -e 's!CONFIG_X86_UP_APIC=y!# CONFIG_X86_UP_APIC is not set!' .config
perl -pi -e 's!CONFIG_X86_UP_IOAPIC=y!# CONFIG_X86_UP_IOAPIC is not set!' .config
%endif

	# make sure EXTRAVERSION says what we want it to say
	LC_ALL=C perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -$extension/" Makefile
	%smake oldconfig
}

BuildKernel() {
	KernelVer=$1
	echo "Building kernel $KernelVer"

	%kmake all

	## Start installing stuff
	install -d %{temp_boot}
	install -m 644 System.map %{temp_boot}/System.map-$KernelVer
#	install -m 644 Module.symvers %{temp_boot}/Module.symvers-$KernelVer
	install -m 644 .config %{temp_boot}/config-$KernelVer

	%ifarch alpha
	cp -f arch/alpha/boot/vmlinux.gz %{temp_boot}/vmlinuz-$KernelVer
	%endif
	%ifarch sparc sparc64
	cp -f vmlinux %{temp_boot}/vmlinux-$KernelVer
	%endif
	%ifarch ppc
	cp -f vmlinux %{temp_boot}/vmlinuz-$KernelVer
	cp -f arch/ppc/boot/images/zImage.chrp-rs6k %{temp_boot}/vmlinuz-rs6k-$KernelVer
	%endif
	%ifarch %{ix86}
	cp -f arch/i386/boot/bzImage %{temp_boot}/vmlinuz-$KernelVer
	%endif
	%ifarch x86_64
	cp -f arch/x86_64/boot/bzImage %{temp_boot}/vmlinuz-$KernelVer
	%endif

	# modules
	install -d %{temp_modules}/$KernelVer
	%smake INSTALL_MOD_PATH=%{temp_root} KERNELRELEASE=$KernelVer modules_install 
}

SaveHeaders() {
	flavour=$1
	flavour_name="`echo $flavour | sed 's/-/_/g'`"
%if %build_source
	HeadersRoot=%{temp_source}/savedheaders
	HeadersArch=$HeadersRoot/%{target_cpu}/$flavour
	echo "Saving hearders for $flavour %{target_cpu}"

	# deal with the kernel headers that are version specific
	install -d $HeadersArch
	install -m 644 include/linux/autoconf.h $HeadersArch/autoconf.h
	install -m 644 include/linux/version.h $HeadersArch/version.h
	if [ "$flavour" != "BOOT" ]; then
		grep -e " __crc_" -e " __ksymtab_" System.map > include/linux/symtab-$flavour
	fi
    	echo "%{target_cpu} $flavour_name %{_savedheaders}%{target_cpu}/$flavour/" >> $HeadersRoot/list
%endif
}

CreateFiles() {
	kversion=$1
	output=../kernel_files.$kversion

	echo "%defattr(-,root,root)" > $output
	echo "%{_bootdir}/config-${kversion}" >> $output
%ifarch sparc sparc64
	echo "%{_bootdir}/vmlinux-${kversion}" >> $output
%else
	echo "%{_bootdir}/vmlinuz-${kversion}" >> $output
%endif
%ifarch ppc
	echo "%{_bootdir}/vmlinuz-rs6k-${kversion}" >> $output
%endif
	echo "%{_bootdir}/System.map-${kversion}" >> $output
#	echo "%{_bootdir}/Module.symvers-${kversion}" >> $output
	echo "%dir %{_modulesdir}/${kversion}/" >> $output
	echo "%{_modulesdir}/${kversion}/kernel" >> $output
	echo "%{_modulesdir}/${kversion}/modules.*" >> $output
	echo "%doc README.kernel-sources" >> $output
	echo "%doc README.Mandrakelinux" >> $output
}

CreateKernel() {
	flavour=$1

	if [ "$flavour" = "up" ]; then
		KernelVer=%{KVERREL}
		PrepareKernel "" %realrelease
	else
		KernelVer=%{KVERREL}$flavour
		PrepareKernel $flavour %{realrelease}$flavour
	fi

	BuildKernel $KernelVer
	SaveHeaders $flavour
        CreateFiles $KernelVer
}


CreateKernelNoName() {
	arch=$1
	nprocs=$2
	memory=$3

        name=$arch-$nprocs-$memory
	extension="%realrelease-$name"

	KernelVer="%{KVERREL}-$arch-$nprocs-$memory"
	PrepareKernel $name $extension
	BuildKernel $KernelVer
	SaveHeaders $name
        CreateFiles $KernelVer
}

###
# DO it...
###

# Create a simulacro of %buildroot
rm -rf %{temp_root}
install -d %{temp_root}

#make sure we are in the directory
cd %src_dir

%if %build_BOOT
CreateKernel BOOT
%endif

%if %build_smp
CreateKernel smp
%endif

%if %build_secure
CreateKernel secure
%endif

%if %build_enterprise
CreateKernel enterprise
%endif

%if %build_i686_up_4GB
CreateKernelNoName i686 up 4GB
%endif

%if %build_p3_smp_64GB
CreateKernelNoName p3 smp 64GB
%endif

%if %build_up
CreateKernel up
%endif

# We don't make to repeat the depend code at the install phase
%if %build_source
PrepareKernel "" %{realrelease}custom
%smake -s modules_prepare
#smake -s prepare-all
#install -m 644 %{temp_boot}/Module.symvers-%{KVERREL}  Module.symvers
%endif

###
### install
###
%install
install -m 644 %{SOURCE4}  .
install -m 644 %{SOURCE5}  .


# create post file to preload modules
cat > preload_mods.sh <<EOF
%if %preload_my_mods
for mod in %{my_modules} 
    do 
	grep -q -s "\$mod" /etc/modprobe.preload || \
	/bin/echo -e "\n\$mod" >> /etc/modprobe.preload
    done
%if %build_multimedia
grep "^realcap"  /etc/modprobe.preload &> /dev/null
if [ \$? -ne 0 ] ; then
    	grep "^capability"  /etc/modprobe.preload &> /dev/null
    	if [ \$? -ne 0 ] ; then
%if %preload_realcap
	   /bin/echo -e "\nrealcap" >> /etc/modprobe.preload
%else
	   /bin/echo -e "\nPreloading capability security module,"
	   /bin/echo -e "if you want to activate realtime capabilities"
	   /bin/echo -e "comment out/delete the line containing capability"
	   /bin/echo -e "and add on a new line \"realcap\", and adjust"
	   /bin/echo -e "the realcap module options in /etc/modprobe.conf."
	   
	   /bin/echo -e "\ncapability" >> /etc/modprobe.preload
%endif
	fi
%if %preload_realcap
    	if [ \$? -eq 0 ] ; then
	   perl -pi -e 's;capability;realcap;' /etc/modprobe.preload
	fi
%endif
fi
%endif
%else
echo -e "\nNothing to preload\n".
%endif
EOF


cd %src_dir
# Directories definition needed for installing
%define target_source %{buildroot}/%{_kerneldir}
%define target_boot %{buildroot}%{_bootdir}
%define target_modules %{buildroot}%{_modulesdir}

# We want to be able to test several times the install part
rm -rf %{buildroot}
cp -a %{temp_root} %{buildroot}

# Create directories infastructure
%if %build_source
install -d %{target_source} 

tar cf - . | tar xf - -C %{target_source}
# ln -sf linux-%{KVERREL} %{buildroot}/usr/src/linux
chmod -R a+rX %{target_source}

# we remove all the source files that we don't ship

# first architecture files
for i in arm cris ia64 mips mips64 parisc s390 s390x sh sh64 arm26 h8300 m68knommu v850; do
	rm -rf %{target_source}/arch/$i
	rm -rf %{target_source}/include/asm-$i
done

%ifnarch alpha
	rm -rf %{target_source}/arch/alpha
	rm -rf %{target_source}/include/asm-alpha
%endif

%ifnarch sparc sparc64
	rm -rf %{target_source}/arch/sparc
	rm -rf %{target_source}/arch/sparc64
	rm -rf %{target_source}/include/asm-sparc
	rm -rf %{target_source}/include/asm-sparc64
%endif

# ppc needs m68k headers, but not arch
	rm -rf %{target_source}/arch/m68k
%ifnarch ppc ppc64
	rm -rf %{target_source}/arch/ppc
	rm -rf %{target_source}/arch/ppc64
	rm -rf %{target_source}/include/asm-m68k
	rm -rf %{target_source}/include/asm-ppc
	rm -rf %{target_source}/include/asm-ppc64
%endif

%ifnarch %{ix86} x86_64 amd64
	rm -rf %{target_source}/arch/i386
	rm -rf %{target_source}/arch/x86_64
	rm -rf %{target_source}/include/asm-i386
	rm -rf %{target_source}/include/asm-x86_64
%endif

# remove config split dir
rm -rf %{target_source}/include/config

# other misc files
rm -f %{target_source}/{.config.old,.config.cmd}

# We need this to prevent someone doing a make *config without mrproper
touch %{target_source}/.need_mrproper

pushd %{target_source}/include/linux ; {
install -m 644 %{SOURCE15} rhconfig.h
rm -rf autoconf.h version.h
# Create autoconf.h file
echo '#include <linux/rhconfig.h>' > autoconf.h
sed 's,$,autoconf.h,' %{_savedheaders}list | awk -f %{SOURCE16} >> autoconf.h
# Create version.h
echo "#include <linux/rhconfig.h>" > version.h
loop_cnt=0
for i in BOOT up smp enterprise secure i686-up-4GB p3-smp-64GB; do
	if [ -d %{_savedheaders}%{target_cpu}/$i -a \
	     -f %{_savedheaders}%{target_cpu}/$i/version.h ]; then
		name=`echo $i | sed 's/-/_/g'`
		if [ $loop_cnt = 0 ]; then
      			buf="#if defined(__module__$name)"
    		else
 	     		buf="#elif defined(__module__$name)"
    		fi
		echo "$buf" >> version.h
		grep UTS_RELEASE %{_savedheaders}%{target_cpu}/$i/version.h >> version.h
		loop_cnt=$[loop_cnt + 1]
	fi
done
#write last lines
if [ $loop_cnt -eq 0 ]; then
	echo "You need to build at least one kernel"
	exit 1;
fi
echo "#else" >> version.h
echo '#define UTS_RELEASE "'%{KVERREL}custom'"' >> version.h
echo "#endif" >> version.h

# Any of the version.h are ok, as they only differ in the first line
ls %{_savedheaders}%{target_cpu}/*/version.h | head -n 1 | xargs grep -v UTS_RELEASE >> version.h
rm -rf %{_savedheaders}
} ; popd
#endif %build_source
%endif

# We used to have a copy of PrepareKernel here
# Now, we make sure that the thing in the linux dir is what we want it to be
# Gzip module and relink the link to a .gz module

find %{target_modules} -type f -name '*.ko'|xargs gzip -9f
for i in $(find %{target_modules} -type l -name '*.ko');do
    link=$(LC_ALL=C perl -e 'print readlink shift, "\n"' $i)
    ln -s $link.gz $i.gz
    rm -f $i
done

for i in %{target_modules}/*; do
  rm -f $i/build $i/modules.*
  rm -rf  $i/pcmcia/
done

# sniff, if we gzipped all the modules, we change the stamp :(
# we really need the depmod -ae here

pushd %{target_modules}
for i in *; do
	/sbin/depmod-25 -u -ae -b %{buildroot} -r -F %{target_boot}/System.map-$i $i
	echo $?
done

for i in *; do
	pushd $i
	echo "Creating module.description for $i"
	find . -name "*.ko" -o -name "*.ko.gz" \
	|xargs -i echo 'echo -ne `basename {}`"\t\t"; echo `/sbin/modinfo-25 -d {}`' \
	> get-desc.sh
	sh get-desc.sh > modules.desc
	rm get-desc.sh
        #modules=`find . -name "*.ko" -o -name "*.ko.gz"`
        #/sbin/modinfo-25 -F 'description' $modules \
        #| perl -lne 'print "$1\t$3" if m|([^/]*)\.ko(\.gz)? "(.*)"|'  > modules.description
	popd
     done
popd




###
### clean
###

%clean
rm -rf %{buildroot}
# We don't want to remove this, the whole reason of its existence is to be 
# able to do several rpm --short-circuit -bi for testing install 
# phase without repeating compilation phase
#rm -rf %{temp_root} 

###
### scripts
###

%define options_preun -a -R -S -c
%define options_post -a -s -c -L

%preun
/sbin/installkernel %options_preun %{KVERREL}
exit 0

%post -f preload_mods.sh
/sbin/installkernel %options_post %{KVERREL}




%postun
/sbin/kernel_remove_initrd %{KVERREL}


%preun -n %{kname}-smp-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}smp
exit 0


%post -n %{kname}-smp-%{mdkversion} -f preload_mods.sh
/sbin/installkernel %options_post %{KVERREL}smp


%postun -n %{kname}-smp-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}smp


%preun -n %{kname}-enterprise-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}enterprise
exit 0

%post -n %{kname}-enterprise-%{mdkversion} -f preload_mods.sh
/sbin/installkernel %options_post %{KVERREL}enterprise


%postun -n %{kname}-enterprise-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}enterprise


%preun -n %{kname}-BOOT-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}BOOT
exit 0

%post -n %{kname}-BOOT-%{mdkversion} -f preload_mods.sh
/sbin/installkernel %options_post %{KVERREL}BOOT

%postun -n %{kname}-BOOT-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}BOOT


%preun -n %{kname}-secure-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}secure
exit 0

%post -n %{kname}-secure-%{mdkversion} -f preload_mods.sh
/sbin/installkernel %options_post %{KVERREL}secure

%postun -n %{kname}-secure-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}secure


%preun -n %{kname}-i686-up-4GB-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}-i686-up-4GB
exit 0

%post -n %{kname}-i686-up-4GB-%{mdkversion} -f preload_mods.sh
/sbin/installkernel %options_post %{KVERREL}-i686-up-4GB


%postun -n %{kname}-i686-up-4GB-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}-i686-up-4GB


%preun -n %{kname}-p3-smp-64GB-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}-p3-smp-64GB
exit 0

%post -n %{kname}-p3-smp-64GB-%{mdkversion} -f preload_mods.sh
/sbin/installkernel %options_post %{KVERREL}-p3-smp-64GB

%postun -n %{kname}-p3-smp-64GB-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}-p3-smp-64GB


%post -n %{kname}-source
cd /usr/src
rm -f linux
ln -snf linux-%{KVERREL} linux
/sbin/service kheader start 2>/dev/null >/dev/null || :
# we need to create /build only when there is a source tree.

for i in /lib/modules/%{KVERREL}*; do
	if [ -d $i ]; then
		ln -sf /usr/src/linux-%{KVERREL} $i/build
	fi
done

%postun -n %{kname}-source
if [ -L /usr/src/linux ]; then 
    if [ -L /usr/src/linux -a `ls -l /usr/src/linux 2>/dev/null| awk '{ print $11 }'` = "linux-%{KVERREL}" ]; then
	[ $1 = 0 ] && rm -f /usr/src/linux
    fi
fi
# we need to delete <modules>/build at unsinstall
for i in /lib/modules/%{KVERREL}*/build; do
	if [ -L $i ]; then
		rm -f $i
	fi
done
exit 0

###
### file lists
###

%if %build_up
%files -f kernel_files.%{KVERREL}
%endif

%if %build_smp
%files -n %{kname}-smp-%{mdkversion} -f kernel_files.%{KVERREL}smp
%endif

%if %build_enterprise
%files -n %{kname}-enterprise-%{mdkversion} -f kernel_files.%{KVERREL}enterprise
%endif

%if %build_BOOT
%files -n %{kname}-BOOT-%{mdkversion} -f kernel_files.%{KVERREL}BOOT
%endif

%if %build_secure
%files -n %{kname}-secure-%{mdkversion} -f kernel_files.%{KVERREL}secure
%endif

%if %build_i686_up_4GB
%files -n %{kname}-i686-up-4GB-%{mdkversion} -f kernel_files.%{KVERREL}-i686-up-4GB
%endif

%if %build_p3_smp_64GB
%files -n %{kname}-p3-smp-64GB-%{mdkversion} -f kernel_files.%{KVERREL}-p3-smp-64GB
%endif

%if %build_source
%files -n %{kname}-source
%defattr(-,root,root)
%dir %{_kerneldir}
%dir %{_kerneldir}/arch
%dir %{_kerneldir}/include
%{_kerneldir}/.config
%{_kerneldir}/COPYING
%{_kerneldir}/CREDITS
%{_kerneldir}/Documentation
%{_kerneldir}/MAINTAINERS
%{_kerneldir}/Makefile
%{_kerneldir}/README
%{_kerneldir}/REPORTING-BUGS
%ifarch alpha
%{_kerneldir}/arch/alpha
%endif
%ifarch %{ix86} x86_64 amd64
%{_kerneldir}/arch/i386
%endif
#%{_kerneldir}/arch/ia64
%ifarch ppc ppc64
%{_kerneldir}/arch/ppc
%{_kerneldir}/arch/ppc64
%endif
%ifarch sparc sparc64
%{_kerneldir}/arch/sparc
%{_kerneldir}/arch/sparc64
%endif
%ifarch %{ix86} x86_64 amd64
%{_kerneldir}/arch/x86_64
%endif
%{_kerneldir}/arch/um
%{_kerneldir}/cluster
%{_kerneldir}/crypto
%{_kerneldir}/drivers
%{_kerneldir}/fs
%{_kerneldir}/init
%{_kerneldir}/ipc
#{_kerneldir}/kdb
%{_kerneldir}/kernel
%{_kerneldir}/lib
%{_kerneldir}/mm
%{_kerneldir}/net
%{_kerneldir}/security
%{_kerneldir}/scripts
%{_kerneldir}/sound
%{_kerneldir}/usr
%{_kerneldir}/3rdparty
%{_kerneldir}/include/acpi
%{_kerneldir}/include/asm
%ifarch alpha
%{_kerneldir}/include/asm-alpha
%endif
%{_kerneldir}/include/asm-generic
%ifarch %{ix86} x86_64 amd64
%{_kerneldir}/include/asm-i386
%endif
#%{_kerneldir}/include/asm-ia64
%ifarch ppc
%{_kerneldir}/include/asm-m68k
%{_kerneldir}/include/asm-ppc
%{_kerneldir}/include/asm-ppc64
%endif
%ifarch sparc sparc64
%{_kerneldir}/include/asm-sparc
%{_kerneldir}/include/asm-sparc64
%endif
%ifarch %{ix86} x86_64 amd64
%{_kerneldir}/include/asm-x86_64
%endif
%{_kerneldir}/include/asm-um
%{_kerneldir}/include/cluster
%{_kerneldir}/include/linux
%{_kerneldir}/include/math-emu
%{_kerneldir}/include/net
%{_kerneldir}/include/pcmcia
%{_kerneldir}/include/scsi
%{_kerneldir}/include/sound
%{_kerneldir}/include/video
%{_kerneldir}/include/media
%{_kerneldir}/include/rxrpc
%{_kerneldir}/.need_mrproper
%doc README.kernel-sources
%doc README.Mandrakelinux
#endif %build_source
%endif

%if %build_doc
%files -n %{kname}-doc
%defattr(-,root,root)
%doc linux-%{tar_version}/Documentation/*
%endif

%changelog
* Wed Jul 28 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.31mdk
- fix compilation under 2.4 kernel
	MG92_omnibook_Makefile_fix_alt1.patch
- ipw2100-0.51
- reenable prism25 usb and plx on smp
	MB80_1prism25-0.2.1-pre21.tar
- ov511 update to latest version and mark in kernel driver "old"
	MB90_ov511-2.28.tar
	MB91_ov511_mark_in-kernel_driver_as_old.patch
- readd old marvel driver (doesn't need fb support)
	MH00_mod_marvel-cvs20031215.tar
- merge rest of 3rdparty update from main kernel
	MC30_at76c503a-cvs20072004.tar
	MC70_acecad-3.1.tar
	MC71_acecad-3.1-hid.patch
	ZG12_dazuko-2.0.2.tar

* Mon Jul 26 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.30mdk
- bttv & co 20040723-010612
- dri-20040726
- lpfcdriver-2.6-8.0.7
- software suspend 2.0.0.100
  (+ boot fix for more then one swap partition)
- sync with most of 2.6.8-rc2q2's 3rdparty
	eagle-usb-1.9.8
	hostap-0.2.4
	dfg1394-1.3
	prism25-0.2.1-pre21
	ndiswrapper-0.8
	fuse-1.3
	shfs-0.35
	ipw2100-0.50

* Mon Jul 26 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.29mdk
- revert to device mapper 2.6.7-rc3-udm1
- bttv & co updates
- move omnibook support to 3rdparty MG90 & MG91
  and update it to 20040701 release
- ivtv-0.1.10-pre2-ck100i

* Fri Jul 23 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.28mdk
- add "--with nfs" for built-in nfs support
  by default nfs support is configured as module
- turn NLS support to built-in not module
  to please livecd
- add boot parameter to enable/disable swsusp2's acpi S4 support
	suspend_acpi and suspend_noacpi respectively
	with those options you can overide the default
	configuration which currenlty is disabled as
	it breaks certain Sony laptops

* Thu Jul 22 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.27mdk
- fix building of alsa's addons 
  emu10k1x and audigyls after move to 3rdparty

* Thu Jul 22 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.26mdk
- fix acpi processor module unload
- added planet ccrma dri low latency patches
	you need to rebuild with "--with drill"
	modified drivers are mga, r128, radeon
	don't enable this unless you now what you are doing

* Wed Jul 21 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.25mdk
- device mapper 2.6.7-udm1
- alsa cvs 20040720 
	( echoaudio and tvmixer are broken with new alsa,
	  use older kernel if you need them)

* Wed Jul 21 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.24mdk
- swsusp2 fixes: 
	- merge acpi-S4 config option from 2.0.0.99 
	  and disable it (breaks power off if enabled)
	- merge progressbar fix from 2.0.0.100
	- change version to 2.0.0.98sds :-)

* Mon Jul 19 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.23mdk
- gatos km cvs20040719
- ivtv-0.1.10-pre2-ck100b
- fix smp build 
  (revert smp support for acpi processor driver - unresolved symbols )
- renumber all 3rdparty drivers/patches ala -tmb
- fix ibmcrypto compile
- move ipw2100 to 3rdparty 
  (it's not going to be merged soon)
- move hostap to 3rdparty
- move fuse and lufs to 3rdparty
- turn CONFIG_UNIX to "y" (from "m")

* Sat Jul 17 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.22mdk
- acpi-20040715-2.6.7

* Sat Jul 17 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.21mdk
- ieee1394 r1233
- dvb-cvs20040717
- usbvision0.9.6cvs20040717
- spca5xx_26x-10072004
- add zr364xx-0.52
- add vpx3224 and v3tv-radio
- add alsa tvmixer driver
- move all alsa patches to DSxx (xx == 00 - 49)
- tiny resync with Thomas
	squashfs_2.0
	mppe-mppc-1.0

* Fri Jul 16 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.20mdk
- fix building of the rfswitch modules

* Tue Jul 13 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.19mdk
- i810_audio fix the error path of resource management
- ipw2100-0.49
- dvb-cvs20040714
- dri-cvs20040715
- ivtv-0.1.10-pre2-ck99v
- 2.6.7-mh2
- low latency fixes from 2.6.8rc1-mm1
- add "--without apic" build option to disable apic support

* Tue Jul 13 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.18mdk
- fix swsusp2 boot problems
  now it even works on cooker with gcc-3.4 :-)
- ruby build :
  - turn of vesafb till i dig the debian patch to make it module
  - turn framebuffer console to module

* Sat Jul 10 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.17mdk
- ieee1394r1232
- cpufreq_nforce2
- i810_audio mmio support
- ipmi_si_intf.c warning fix
- dvb-cvs20040709
- xfs-cvs20040709
- translucency-morphix_cvs20040709
- rhineget
- acx_io_width16 only when debug enabled
- cfq fixes
- staircase7.9 + 7.9-opt1.patch
- schedbatch2.3
- schediso2.3
- autotune_swappiness
- config_hz
- voluntary-preempt-2.6.7-bk20-H3
- enable both kernel & voluntary preemtion by default
- software suspend v2.0.0.98 
  (doesn't boot here, just to keep in sync)
- turn cramfs to module

* Wed Jul 07 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.16mdk
- acpi 2.6.7-mm5 (treat with care, good candidate for droping)
- move win4lin in patch tarball
- resync with -ck5
	staircase scheduler 7.9 
	schedbatch 2.2 
	schediso 2.2     
	cfq bad allocation fix

* Tue Jul 06 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.15mdk
- ip_tables DOS fix
- CAN-2004-0497 fix
- proc security fix
- sym_revert_to_2.1.18i 
 (workaround http://bugme.osdl.org/show_bug.cgi?id=bug2994)
- alps psmouse support
- mISDN_cvs_20040705
- forcedeth gige suport
- dvb-20040701
- lids-2.2.0rc2-2.6.7
- enable drm driver for Intel 915
- disable irq sharig for radeon drm driver
  (Radeon IGP troubles ? )

* Thu Jul 01 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.14mdk
- staircase scheduler v7.8
- software-suspend2  2.0.0.90
  (doesn't work if compiled with gcc-3.4 from cooker)
- ieee1394 - allow multiple camera software versions
- another hpt3xx fix

* Mon Jun 28 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.13mdk
- staircase scheduler v7.7
- xfs-cvs20040628
- dmapi-cvs20040628
- xfs dmapi support
- jfs dmapi support
- packet writing update
- i2c add adm1031 & adm1025
- merge kernel-ruby "--with ruby"
  ruby-2.6.7
- enable gfs & co + drbd on alpha
 
* Sun Jun 27 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.12mdk
- staircase scheduler v7.6

* Sat Jun 26 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.11mdk
- fix unpackaged file in kernel-source

* Sat Jun 26 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.10mdk
- isofs fixes from linus tree
	fix_handling_of_inodes_beyond_4GB
	isofs_nfs_fix
	fix_handling_of_slash_embedded_in_filenames_in_isofs
	isofs_fix_ignoring_noexec_and_mode_mount_options
- limit max sectors to_ 566 for PDC20265
- cpufreq-2004-06-25
- agpgart-2004-06-25
- at76c503a-0.12Beta14
- ivtv-0.1.10-pre2-ck97h
- rivatv-cvs20040626
- drop ogfs in favour of GPL'd gfs:
	cman, dlm, lock_harness, gfs, gnbd
	lock_nolock, lock_dlm, lock_gulm
- drbd-0.7_pre8
- update win4lin patches and "--with win4lin

* Fri Jun 25 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.9mdk
- staircase scheduler v7.4

* Fri Jun 25 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.8mdk
- Back to -sds6 but move swsusp2 to a "--with swsusp2" option
  after all it is the cause for the  misterious boot problems.
  If you use the above option kernel will be named kernel-swsusp2.  

* Thu Jun 24 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.7mdk
- rever to sds5 and drop input updates
  to track boot hangs

* Wed Jun 23 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.6mdk
- x86_64-2.6.7-2 patchkit
- usb & ntfs updates from 2.6.7-mm2
- drop DU16_usb-pen_fix.patch 
  (should be fixed by the usb update)
- ieee1394 rev1230
- ipw2100-0.46_3
- prism54-1.2
- orinoco-0.15rc1cvs20040624
- dri-cvs20040624
- dvb-cvs20040623
- dell-laptop lockup fix for alsa
- fix the reiser4 fix for arch !X86
- disable swsusp2 on smp
- VIA V-link handling bugfix

* Wed Jun 23 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.5mdk
- staircase scheduler v7.3

* Mon Jun 21 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.4mdk
- software suspend v2 (2.0.88 for 2.6.7)
  pretty much testing stuff, but you might have luck

* Mon Jun 21 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.3mdk
- ipmi updates & fixes
- hpfs fixes
- exaudio-1.62
- viafb_02
- input updates
- mISDN_cvs_20040620
- prism54_usb-cvs20040621
- lids-2.2.0rc1
- bluetooth 2.6.7-mh1
- staircase scheduler v7.1
- alpha - enable some new drivers :
	packetcdvd, prism54, prism54usb, acx_pci, acx_usb,
	iteraid, isdn, mISDN, usb-cpad,cxacru 

* Fri Jun 18 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.2mdk
- fix endless loop in SCSI_SPI_transport_class
  (may be fix scsi sym problems)
- bttv & co updates
- cmpci devexit fix
- nvidia sata libata driver
- reiser4 fixlet for !x86 arches
- drop linux-abi
  breaks ppc/alpha/(put your !x86 arch here)
- ppc :
	disable sysfb & sys dri 
	enable preemtation on UP
	enable reiser4
- make it build on alpha
  disable broken options(isa_virt..)
	CONFIG_SCSI_7000FASST
	CONFIG_ELPLUS
	CONFIG_3C515
	CONFIG_LANCE
	CONFIG_NI52
	CONFIG_NI65
	CONFIG_CS89x0
	CONFIG_DIGIEPCA
	CONFIG_ESPSERIAL=m
	CONFIG_SYNCLINK=m
	CONFIG_RIO=m
	CONFIG_QIC02_TAPE=m
	CONFIG_FTAPE=m
	CONFIG_USB_GADGET=m

* Wed Jun 16 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-q1.sds.1mdk
- merge 2.6.7 final
- audigyls 20040612
- squashfs 2.0
- make nls_default a runtime option
- drop acpi bk updates
  (and hopefully fix the serial issues)
- drop dynamic-timeslice in favour of con's work:
	2.6.7-rc3-s6.E.patch
	2.6.7-rc3.s6.D-schedrange.patch
	2.6.7-rc3.schedrange-batch.patch
	2.6.7-rc3.batch-iso.patch
- various small fixes:
	unregister-driver-if-probing-fails-in-sb_cardc
	sound_opti92x-ad1848-locking-fix
	remove-irda-usage-of-isa_virt_to_bus
	pcmcia-enable-read-prefetch-on-o2micro-bridges-to-fix-hdsp
	fix-memory-leak-in-swsusp
	pmdisk-memleak-fix

* Mon Jun 07 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-rc3q1.sds.1mdk
- resync with linus & various bk trees
	linus-2.6.7rc3mm1
	bk_2.6.7rc3mm1-acpi
	bk_2.6.7rc3mm1-driver-core
	bk_2.6.7rc3mm1-pci
	bk_2.6.7rc3mm1-scsi
	bk_2.6.7rc3mm1-input
	bk_2.6.7rc3mm1-i2c
	bk_2.6.7rc3mm1-netdev
	bk_2.6.7rc3mm1-usb
	bk_2.6.7rc3mm1-agpgart
	bk_2.6.7rc3mm1-cifs
	bk_2.6.7rc3mm1-ntfs

- smbfs nautilus oops workaround
  bugzilla_id_1671
- disable udf debugging
- dri-cvs20040608
- hostap-0.2.2cvs20040609
- qcamvc-1.0.7cvs20040608
- acx100-0.2.0pre8_plus_fixes_12
- translucency-cvs20040609 (morphix.sf.net)
- linux-abi-2.6.6

* Mon Jun 07 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-rc2q1.sds.5mdk
- don't rebuild aic7xxx firmware
- p4p800 dmi blacklist fix
- disable acer_hk (broken with gcc-3.4)

* Thu Jun 03 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-rc2q1.sds.4mdk
- reiser4 :
  disk format fix
  rename "metas" to "..metas"
 
* Thu Jun 03 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-rc2q1.sds.3mdk
- maybe fix some serial issues
  drop CE27_make-proliant-8500-boot-with-26.patch
- subfs_submount-0.9
- smylink rework from -mm tree
- reiser4-20040602 and some needed patches from -mm
- merge latest Thomas updates/fixes
  fix nls cp936
  iteraid 1.45

* Mon Jun 01 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-rc2q1.sds.2mdk
- 2.6.7-rc2-bk2
- audigyls 20040530
- alsa 1.0.5a
- nforce ck804 ide support 
- schedstats
- tc1100-wmi
- wacom_acpi
- usblp fix
- agp resume fixups
- bk-drm 20040531
- bk-ntfs 20040531
- 2.6.7-rc2-am11
- mISDN cvs20040601
- lids-2.2.0pre5-2.6.6
- merge more stuff from my 2.6.6rc2 tree
	some ide tweaks
	some kbuild tweaks 
	
* Sun May 30 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-rc2q1.sds.1mdk
- 2.6.7-rc2
- alsa-1.0.5
- audigy ls support
- new bootsplash

* Sat May 29 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-rc1q1.sds.2mdk
- 2.6.7-rc1-bk5
- proliant-8500 boot fix
- radeonfb iBook & IGP fixes
- via-velocity
- 3ware-9000 sata-raid
- isd-300 usb controller
- thinkpad-5.5
- latest bk trees of :
    acpi, agpgart, cpufreq, cifs, i2c
    ntfs, driver-core, usb

* Wed May 26 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.7-rc1q1.sds.1mdk
- start over with 2.6.7-rc1-1mdk
  netfilter patches not merged
  ( as some of my additions)
- drop bootsplash until fixed
  (no time for investigation right now)
- merge 2.6.7-rc1-bk3
- device mapper 2.6.6-udm1
- add alsa-atiixp_modem
- add alsa-emu10k1x
- update sisfb to 210504
- prism54-cvs20040526.patch
- 3ware-9000 sata-raid
- packet-2.6.6
- broken need_float_conv
	exaudio
	quickcam-vc
	snd-hdspm	
- drop patches without any feature in mdk
	modular OOM
	alternate DVB driver
	
* Mon May 17 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-q1.sds.16mdk
- usb-pen fix

* Mon May 17 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-q1.sds.15mdk
- usb input emulation fix is x86 only
- ivtv-0.1.10-pre2-ck67a
- marvel tv caprture(mgatv) cvs 20040516
	(
	by troubles with msp3400 
	: drop a line, will reinclude marvel_msp3400
	)
- aic7xxx-20040513

* Wed May 12 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-q1.sds.14mdk
- nforce2 disconnect fix 
  ( C1halt is gone and shouldnt be neded )
- i810 audio fixes (oss driver)
- ipw2100 fsam7400-0.3.1
- fpi2002-0.1
- cxacru_2003-10-05
- cpad-0.1
- acx100-0.2.0pre8 + fixes6
	old driver still in : acx100_pci
	new driver	    : acx_pci & acx_usb
- spec fixes for non x86 arches 

* Mon May 10 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-q1.sds.13mdk
- me sucks (fix missing space in preload scriplet)
- cfq default io-scheduler
- add ecc driver
- drop two broken ppc fixes
- fix usb compile on ppc & sparc
- ppc config tweaks
  CONFIG_SERIAL_8250=m
  CONFIG_FB_ATY_XL_INIT=n

* Wed May 05 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-q1.sds.12mdk
- sis900 suspend fix
- update and enable realcap lsm
- various ppc fixes
  (libata on ppc is back)

* Mon May 03 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-q1.sds.11mdk
- fast resync with 2.6.5-1.tmb.5mdk
	add workaround for ppp_mppe from 2.4 series
	iteraid 1.44
- fast resync with 2.6.6.0.rc2.1mdk
	usb-storage update
	sk98lin buggy vpd workaround
	cmpci-6.64
	changeloop
	gzloop
- sis900 yield sched timeout

* Thu Apr 29 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-q1.sds.10mdk
- enable pwc compilation
  (marked broken in vanilla 2.6.6-rc2)

* Mon Apr 26 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-q1.sds.9mdk
- bk-acpi-20040426
- bk-scsi-20040426
- bk-usb-20040426
- vesa fbdev update
- bttv & co updates for 2.6.6rc2
- echoaudio-0.8.10
- eagle-usb-1.9.7cvs
- ndiswrapper-0.7
- orinoco-0.15rc1
- crypto_null autoload

* Wed Apr 21 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-q1.sds.8mdk
- preload modules that are build in-kernel in mdk main kernels
  sort of hackish yet
- build classic oom killer staticly if for club	 
- enable pnpbios support for testing
  it has been disabled for ages, it could be already fixed
- add two more build options
	--without scsidrv	:= don't build low level scsi drivers
	--without libatadrv	:= don't build libata drivers


* Wed Apr 21 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-q1.sds.7mdk
- 2.6.6-rc2
- add Tornado id's to 3C920B
- more kbuild fixes
- drop lot of patches merged upstream
- bk-cpufreq-20040419
- bk-netdev-20040419
- revert vga16fb_fix_bad_mapping (unresolved symbols on ppc)
- acer_hk depends on x86
- full merge of objrmap & anonmm
- selinux inode race trap
- slab leak detector
- lockmeter
- rwsem fixes
- scale rwsem
- use tmb configs for non i386 kernels
  lot of stuff needs enabling, but no hardware to test
  crosscompile for ppc fails oddly
- selective merge with 2.6.3-10mdk
	gzloop (might be broken blkdev_unpluging )
	drm_ioctl32_more_mga_fixes
	max-symlink-to-10
	vfat-nobadchars-option
	supermount-no-warning-when-busy
	CAN-2004-0003-drm_r128
	
* Tue Apr 20 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-q1.sds.6mdk
- ieee1394r1206
- 2.6.5-udm5
- add sata_sii sii3512 id's
- add sata_sis sis964 id's
- sata_sis sis964 hotfix
- via6410 & via6421 id's
- ipw2100-2.6.4-0.40
- 3c509 oops fix
- dyc_ar5k
- cifs-1.0.8-20040418
- nfs3/nfsd3 acl are back in
- move fuse & lufs to fs/
- acer_hk 0.5
- iriver tweak
- ibmcrypto
- warn if module_param and module_parm mixed
- ehci oops fix
- sysfs d_fsdata race fix
- fix umount after bad chdir
- 2.6.4-amd76x_pm
- nforce2-idleC1halt-rd-2.6.5
- nforce2-ioapic-rd-2.6.5
- win4lin support is back too

* Thu Apr 15 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-q1.sds.5mdk
- lpfcdriver 20040409
- bluetooth 2.6.5-mh3
- CAN-2004-0075-vicam
- CAN-2004-0177-ext3
- modpost warn on missing -fno-common
- drop sysfs symlinks fix (breaks alsa unload)
- fix build of smp & secure kernels
  update & fix lids to 2.2.0pre2-2.6.5 
  fix hpt374 os driver on smp

* Wed Apr 14 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-q1.sds.4mdk
- merge up to 2.6.5-bk2 and 2.6.5-mm5 almost
- CAN-2004-0109 isofs fix
- latest bk trees as of 2004-04-12
  agpgart, cpufreq, driver-core, i2c, netdev, pci, usb
- acpi, pnp & co
  pnp-updates
  acer-travelmate-360 interrupt routing fix
  acpi-processor-load
  acpi-link-tolerant
  acpi_skip_timer_wip
  nmi-1-hz-2
  nmi_watchdog-local-apic-fix
- sound
  echoaudio-0.8.10pre3
  cmpci-6.82
- net
  r8169-warning-fix
  i4l-nullpointer-fix
- scsi & co
  3ware-update
  advansys-fix
  mptlinux-3.01.04
  sym53c500cs
  aic7xxx-swsusp-support
- usb & co
  psmouse-usb-fix-3
  rndis fix
- video & framebuffer support
  viafb
  vesafb-rrc
  dvb-cvs20040331
  mxb-saa7111-update
- fs's
  sysfs symlinks fix
  cifs-1.0.6-20040414
  xfs-laptop-mode
- 2.6.5udm2
- packet-2.6.5
- misc 
  disable-cap-mlock
  nonlinear-can-do-mlock
  writeback-lat
  vmscan-less-sleepiness
  call usermodehelper async
  compute creds race fixes
  poll-select fixes
  class_dev_ip2main
- droped (droped from -mm)
	mm_gang_lookup_next
	truncate_inode_pages-check
	O_DIRECT-race-fixes-rollup

* Wed Apr 07 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-q1.sds.3mdk
cpufreq-2004-04-06
agpgart-2004-04-06
ieee1394r1204
swsusp-update
autofs4 update
scale nr_requests
extend iosched printk
mousedev psaux support add param
IPv4-stealth
saa7134 asus-tv-fm inputs tweak
fix coda old API
udf default uid fix
config-HZ
modular oom kiler
modular mce fix
- scsi tweaks
  sd dont treat nosense as error
  scsi-timeout increase
- usb fixes
  retry some description fetches
  fix xsane hang
  eciadsl fix

* Tue Apr 06 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-q1.sds.2mdk
- usb updates
- bttv & co updates
- alsa-1.0.4
- exaudio-1.59
- revert to working cpufreq
- added --with multimedia 
  to enable realmode capabilities as module
  kernel will be named kernel-sds-mm :-)

* Mon Apr 05 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-q1.sds.1mdk
- 2.6.5 final
- acx100-pre7+fixes6
- packetcdvd for 2.6.5rc3
- dvb (in kernel) drivers should be working again
- various small fixes, updates

* Fri Mar 26 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-0.rc3.sds.1mdk
- 2.6.5-rc3
- drm-cvs20040328
- cifs-1.0.5-bk20040330
- ipw2100-2.6.4-0.39
- orinoco cvs20040328
- mISDN cvs20040329
- hostap-0.2.1 cvs20040329
- acx100-0.2.0pre7+fixes5
- at76c503a-0.12beta9
- alsa-1.0.4-rc2
  ( echoaudio is still broken ) 
- ipr-2.0.1
- iscsi-4.0.1.2
- sata updates (2.6.5rc3-libata1 + sata_speedup)
- powernow-k8 update
- more nfs fixes
- low latency tweaks 
- yenta TI irq routing fix
- alternate dvb driver (check dvb2 modules :-)
- resync with 2.6.4-q1tmb5
  ndiswrapper-0.6
  powermac sysrq fix
  menu cleanups fix
  drm_ioctl32 fixes
  build scsi initio driver
  non i386 configs & spec file
	--with-laptop should be working, but probably not needed
	--with-win4lin is broken & disabled

* Fri Mar 26 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-0.rc2.sds.2mdk
- 2.6.5-rc2-bk6
- kdb-v4.3-2.6.5-rc2-common-1
- radeonfb_old & radeonfb build fix
- ide_cd capacity fix
- logitech keyboard fix
- add i2c-fjkeyinf
- add i2c-smbus-arp
- ipw2100-2.6.4-0.38
- rtl8150-0.6.1
- usb_serial update
- add usb cytherm
- via_drm
- nfsd-acl & xattr
- nfs-acl & xattr
- reiserfs updates
- shfs-0.33
- genksyms fix
- lightweight-auditing-framework updates
- lids-2.2.0pre1-2.6.3
- dazuko-2.0.1-pre2
- rcu for low latency
- asfs-1.0b3_2.6.3

* Wed Mar 24 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-0.rc2.sds.1mdk
- 2.6.5-rc2-bk4
- 2.6.5-rc2-bk3-libata1
- toshiba_acpi_0.18
- ipw2100-0.37
- orinoco-monitor
- fix snd-msnd
- cmpci-6.64
- add snd-serialmidi
- dvd+rw & dvd-rw packtewriting
  ( require usage of ide-scsi )
- libata updates
- cpufreq update
- agp updates
- lightweight-auditing-framework

* Thu Mar 18 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.5-0.rc1.sds.1mdk
- fix oops on lirc-dev unload
- mostly a resync
- various updates
  aic79xx-20040316
  alsa
  bttv & co
  dvb 
  hpt366 fixes
  ieee1394r1193
  ipw2100-0.34
  isdn kcapi
  prism54
  toshiba acpi 0.18
  usb
  various other bitts
- new
  iteraid
  random write cdrom devices with profile 2
- dropped
  CardServices compatibility layer
- broken/ incomplete
  the additional alsa drivers
  - msnd, usx2y, echoaudio
- non i386 configs need to be resynced
- disabled various debug options
- modular nfs, nls, unix, mice

* Tue Mar 16 2004 Svetoslav Slavtchev <svetljo@gmx.de> 2.6.4-1.sds.1mdk
- acpi-20040311
- another hpt366 fix
- bk-scsi
- bk-usb
- bk-pci
- bk-netdev
- watchdog-2.6.4
- ieee1394r1190
- ide-cleanups
- ide-scsi error handling
- isdn_cvs20040315
- mISDN_cvs_20040315
- ipw2100-0.32
- drm add class_dev
- hpfs2-RC4-rc1
- hpfs_namei-RC4-rc1
- xfs-cvs + dmapi
- x86_64-update
- uml-2.6.4-1
- uml-host-skas3
- packet-2.6.4-rc2
- posix message queues
- cfq-5-ionice-schedprio
- 2.6.4-am9
- various alsa fixes by DJ
	gusextreme_error_path
	fix_oops_on_failed_initialisation
	Fix_lots_opses_in_card_probing_routines
	es968_double_free
	Misc_cleanups
	crap_in_sys_after_module_exit
- mdacon is broken on ruby, not vanilla
- 3rdparty updates, additions
	dfg1394-1.1cvs20040314
	dxr3-0.14_20040313
	pvfs2-0.1.1
	
* Thu Mar 11 2004 Thomas Backlund <tmb@mandrake.org> 2.6.4-1.tmb.1mdk
- resync with kernel.org 2.6.4
  * dropped 103 patches merged upstream
- disable packet writing support :-(  until it's updated to 2.6.4

* Thu Mar 11 2004 Thomas Backlund <tmb@mandrake.org> 2.6.3-4.tmb.3mdk
- BadRAM support for ix86 (initial patch by Udo Rader)
  * fixed bug that disabled __free_page(page) if BadRAM is disabled
  * modified so it actually builds with tmb kernels
  * modified so that it's possible to build a kernel with it disabled
  * add BadRAM info to /proc/meminfo 
- clean 3rdparty mod_marvel tarball
- remove 3rdparty Makefile with mrproper, as it's autogenerated
- set CONFIG_8139_RXBUF_IDX=2, was set for embedded systems...  :-( 
- ndiswrapper 0.5
- Intel Pro Wireless 2100 (centrino) 0.29
- update sis190 and sis900 nics
- update pcnet32 to 1.28, fixes hangs
- updated alpha and sparc64 configs (Stefan)
- updated ppc config (Danny)
- aic79xx 20040209 (svetljo)
- acpi 2004020 (svetljo)
- add support for scsi media changers (svetljo)
- alsa 1.0.3 (svetljo)
  * update usx2y, msnd, pdplus patches
  * update to echoaudio 0.8.8rc1
  * add support for Intel8x0 and AMD768/8111 based modems
  * add support for RME Hammerfall DSP MADI soundcards
  * add support for ATI IXP 150/200/250 AC97 controller
- ieee1394 firewire rev 1181 (svetljo)
- update adaptec i2o dpt raid controllers (svetljo)
- add support for HP OmniBook (svetljo)
- update Permedia2 driver (svetljo)
- update ATI IXP IDE support (svetljo)
- fix matroxfb yres virtual (svetljo)
- add support for modular vesafb (svetljo)
- add support for tahoe 9xx serial cards (svetljo)
- add support for Berkshire Products USB-PC watchdog (svetljo)
- update video drivers: (svetljo)
  * cpia, v4l, bt832, tuner, bttv, saa7134, cx88, i2c, zoran
  * update documentation
- add saa5546a Teletext support (svetljo)
- update cifs to 1.04bk20040229 (svetljo)
- ext3 support for online resizing (svetljo)
- update hfs and add support for hfsplus (svetljo)
- update umsdos support (svetljo)
- add support for ufs2 filesystem (svetljo)
- update udf support (svetljo)
- update xfs support (svetljo)
- hostap 0.2.1 cvs 20040303 (svetljo)
- prism54 cvs 20040229 (svetljo)
- prism25 0.2.1-pre20 (svetljo)
- bcm5700 7.1.22 (svetljo)
- at76c503a 0.12Beta7 (svetljo)
- fuse 1.1 final (svetljo)
- usbvision 0.9.6 (svetljo)
- ogfs cvs20040302 (svetljo)
- Gatos ATI AIW capture driver (svetljo)
- cdfs 2.6.3 (svetljo)
- NOARP ARP filter 2.0.0 (svetljo)
- exaudio 1.58 (svetljo)
- updates and addons for device-mapper: (svetljo)
  * transparent device encryption
  * support mutipath hardware
  * snapshot, mirror, kcopycd support
  * bad block relocation support
  * evms support
  * lock fixes, bugfixes, updates...
- packet writing support (svetljo)
- add sysfs classes ppp, raw, vc (svetljo)
- add modular support to mce handler (svetljo)
- dbus over netlink socket support (svetljo)
- fix vc init race (svetljo)
- add support for Linux event logging (svetljo)
- mark mda console broken (svetljo)
- cloop 2.0.1 (svetljo)
- support IBM RAS Service processor (svetljo)
- add support for Cirrus PD6729 Compatible bridge support (svetljo)
- add support for IBM Power Linux RAID adapters (svetljo)
- add support for Swappiness Autoregulation (svetljo)
- add support for USB EPCAM Cameras (svetljo)
- acx100 0.2.0-pre7 + 20040219 updates and fixes (svetljo)
- spca5x video driver 20040228 (svetljo)
- quickcam-vc 1.0.7 (svetljo)
- fix Intel e1000 hang (svetljo)
- update dvb support: (svetljo)
  * docs, saa7134, skystar, frontends, stv0299, tda1004x, av7110, ttusb

* Sun Mar 07 2004 Thomas Backlund <tmb@mandrake.org> 2.6.3-4.tmb.2mdk
- quiet down atkbd warnings...
- require gcc 3.3.2-6mdk or newer since I build with -funit-at-a-time
- remove qla2xxx from 3rdparty as it's already in main kernel.org
  * move qla addons from 3rdparty to main scsi qla tree
- fix kdb kernel debugger (Douglas Wilkins)
  * minor -> MINOR
  * kdb belongs in kern_table, not in fs_table
- fix rmmod hang (svetljo)
- add support for mppe (svtljo)
- make quiet mode real quiet (svetljo)
- block ide-scsi for ide cdroms (svetljo)
- enable Silicon Image Serial ATA (svetljo)
- fix 3rdparty merge lost in sync with main (svetljo)

* Mon Mar 02 2004 Thomas Backlund <tmb@mandrake.org> 2.6.3-4.tmb.1mdk
- sync with main 2.6.3-4mdk
  * netfilter rtsp.
  * dcache security fix.
  * usb released wait on deregister bus.
  * usb-storage update.
  * ICH6 piix/libata support.
  * aacraid update.
  * sk98lin update.
  * mtp fusion update to 3.00.03.
  * ext3 fix access POSIX compiliant.
  * pm runtime deadlock fix.
  * sg direct io allowed as default.
  * bdclaim security oops fix.
  * blacklist Compaq ProLiant DL360 (acpi=off).
  * ipmi v30 (erwan request).
- fixed configs for alpha and sparc64 (Stefan)
-

* Tue Feb 24 2004 Thomas Backlund <tmb@mandrake.org> 2.6.3-2.tmb.1mdk
- sync with main 2.6.3-2mdk
  * bootsplash compil depend fix (chmou).
  * no more ide cdrom use ide-scsi.
  * fix libata pci quirks (remove 0x24d1).
  * parport updates.
  * enable ATM in BOOT kernel (tv request).
- a few fixes from alsa cvs
  * emu10k, ac97, cmipci

* Tue Feb 24 2004 Thomas Backlund <tmb@mandrake.org> 2.6.3-1.tmb.3mdk
- make sure scsi initio is built too
- add -funit-at-a-time back

* Sun Feb 22 2004 Thomas Backlund <tmb@mandrake.org> 2.6.3-1.tmb.2mdk
- fix bootsplash

* Sun Feb 22 2004 Thomas Backlund <tmb@mandrake.org> 2.6.3-1.tmb.1mdk
- fully synced with kernel-2.6.3.1mdk
- build i686-up-4GB kernel too
- i2c fixes
- add Asus P4B533-V to pci quirks

* Mon Feb 16 2004 Thomas Backlund <tmb@mandrake.org> 2.6.2-1.tmb.2mdk
- selected fixes from kernel-2.6.2.3mdk
  * pmpbios off by default
  * 8259 timer ack fix
  * selinux enforce node fix
  * xattr error checking fix
  * smb uid/gid permission fix
- modify alpha.config (stefan)
- disable ia64 support
- drop CP02_nforce2_disconnect_quirk
  * raises cpu temp about 6 degrees C according to acpi-devel ML :(
- drop CP03_nforce2_apic_io-edge_fix
  * does not work anymore
- redo CP05 for correct patches to mpparse on ix86 and amd64
- drop CA10_pcix-enhanced.patch
  * this is the one that breaks nforce2 systems
- drop DA20_sysfs-class-10-vc.patch
  * this still triggers the tty locking race (akpm)
- make sure kernel-source is readable by all (chmod -R a+rX)
- disable -funit-at-a-time for now, seems to break current gcc

* Sun Feb  8 2004 Thomas Backlund <tmb@mandrake.org> 2.6.2-1.tmb.1mdk
- fully synced with kernel-2.6.2.1mdk
- add 2.6.3-rc1 as a patch (so we don't change version)
  * includes alsa 1.0.2c
  * network fixes, netfilter fixes
  * sisfb updated
  * scsi fixes, aha152x fixes
  * + lots of other fixes...
- add sparc/sparc64 configs & fixes done on sparc.eijk.nu
- switch on smp and BOOT for sparc/sparc64
- add alpha configs & fixes done on alpha.eijk.nu
- switch on smp and BOOT for alpha
- modifications to lufs 0.9.7 (jaco)
  * Preserve LUFS filesystem uid/gid's if configured
  * Allow external links if configured
- usb pwc 9.0 beta1 (request by Warly)
- pci.ids 20040207tmb
- build i386 and amd64 with -funit-at-a-time if compiler supports it
- updated requirements for build / install:
  * module-init-tools >= 3.0-0.pre9.2mdk
  * modutils >= 2.4.26-3mdk
  * mkinitrd >= 3.5.18-3mdk
  * bootloader-utils >= 1.6-4mdk

* Wed Jan 28 2004 Thomas Backlund <tmb@mandrake.org> 2.6.2-0.rc2.1.tmb.2mdk
- fix pre/rc kernel versioning...
- redo DA10: alsa 1.0.2 patch
  * alsa developers reuploaded the tarball with a few fixes
    without other notice than the bugtracker :(
  * make sure we display correct alsa version: 1.0.2

* Tue Jan 27 2004 Thomas Backlund <tmb@mandrake.org> 2.6.2-0.rc2.1.tmb.1mdk
- 2.6.2-rc2
- alsa 1.0.2
- forcedeth 0.22
- squashfs 1.3r3
- pci.ids 20040125tmb
- sync with 2.6.2-0.rc1.1mdk
  * force inline memcmp when use Os (gb)
  * slim BOOT kernel.
  * ndis wrapper 0.4.
  * acpi 20031203.
  * raid6 20040107.
  * nfs/nfsd updates.

* Wed Jan 20 2004 Thomas Backlund <tmb@mandrake.org> 2.6.1-1.tmb.10mdk
- argh... me sucks... agp stuff should stay as modules

* Tue Jan 20 2004 Thomas Backlund <tmb@mandrake.org> 2.6.1-1.tmb.9mdk
- 2.6.1-bk6
- sync with -mm5
- dropped ramdisk leak patches CF03, CF04 (mm5: was wrong)
- dropped DA32_ide-siimage-stack-fix (mm5: needs to be reworked)
- dropped ppc64 fixes CB01-CB07 (merged upstream)
- dropped CF01, CF02, DA33, DA41, DF02, DF03, DN21 (merged upstream)
- dropped remove_CardServices DO01 - DO07 (merged upstream)
- dropped v4l patches DV21-DV30 (merged upstream)
- dropped ext2/3 fixes FE01-FE04, xfs FX01 (merged upstream)
- dropped BA01, BA03, BI03, FA05, FJ01, ME01, ME02 (merged upstream)
- dropped acpi CE05-CE08, kdb CK01-CK03, CM01, CM03 (merged upstream)
- dropped sysfs patches MS01-MS05, MS07-MS09 (merged upstream)
- resync DA10_alsa_1.0.1, DA22_alsa_bt87x
- resync DC01 pci.ids.tmb
- resync FA04_invalidate_inodes-speedup
- resync FA08_O_DIRECT-race-fixes-rollup
- CA02: define MAX_INIT_ARGS/ENVS 32 to support more kernel args (Jaco)
- FS01: upgrade supermount-ng to 2.0.4-2.6.1

* Mon Jan 19 2004 Thomas Backlund <tmb@mandrake.org> 2.6.1-1.tmb.8mdk
- 2.6.1-bk4
- drop patches: (merged upstream)
  * DA01-DA07, DA19, DA36-DA38, DF05
- resynced patches DV01-DV16 and moved to DV20-DV30 (v4l)
- make some more drivers modules instead of builtin...
- from -mm4:
  * update libata 0.52
  * pcmcia CardService updates
  * sysfs support
  * readd alsa sysfs
  * md blockdevice fixes
  * restore HT detection algoritm
  * ramdisk and fixes and cleanup
  * ali m1533 dma hang fix
  * change BUG to BUG_ON calls for code speedup
  * laptop mode support
  * fix msi megaraid id
  * fix keyboard scancode to keep 2.4 compability
  * fix kernel-locking doc tmplate
- scsi aic79xx 20031222 (svetljo)
- cifs 1.00 (svetljo)
- 3rdparty qc-usb 0.6.0 (svetljo)

* Tue Jan 13 2004 Thomas Backlund <tmb@mandrake.org> 2.6.1-1.tmb.7mdk
- fix changelog for 5mdk
- add initial support more arches
  * alpha, ia64, x86_64, sparc, sparc64
  * add configs for all above (based on 2.6.1 defconfigs)
  * enable them in the scripts
  * please tell me what you want changed in the configs,
    as I don't have the h/w myself...
- drop loop related patches DB21-DB27 gotten from -mm as they 
  are broken (svetljo)
- gzip modules to minimize needed space for installed kernel
- make apm support builtin, not as module

* Mon Jan 12 2004 Thomas Backlund <tmb@mandrake.org> 2.6.1-1.tmb.6mdk
- back out drm/dri 20040107cvs (seems to cause xfree hangs)
- fix changelog typos for 1mdk to 4mdk

* Sun Jan 11 2004 Thomas Backlund <tmb@mandrake.org> 2.6.1-1.tmb.5mdk
- drop pnp-fix-1, makes kernel oops with Bad EIP (svetljo)
- dont depend on udev and sysfsutils, atleast for now (svetljo)

* Sun Jan 11 2004 Thomas Backlund <tmb@mandrake.org> 2.6.1-1.tmb.4mdk
- keep BLK_DEV_MD builtin, not as a module

* Sun Jan 11 2004 Thomas Backlund <tmb@mandrake.org> 2.6.1-1.tmb.3mdk
- another quick fix... (me sux again :-()
- fix 3rdparty config... (svetljo)
- fix unpackaged files
- disable BLK_DEV_IDEPNP
- sync some more of the configs from kernel-2.6 in contribs

* Sat Jan 10 2004 Thomas Backlund <tmb@mandrake.org> 2.6.1-1.tmb.2mdk
- bugfix for broken sound, me sux :-(
- drop the alsa sysfs patch until all sysfs patches are added...

* Sat Jan 10 2004 Thomas Backlund <tmb@mandrake.org> 2.6.1-1.tmb.1mdk
- 2.6.1
- add --with nosrc option to build nosrc.rpm
- fix typo in description (jaco)
- disable CONFIG_REISERFS_CHECK
- disable IEEE1394_OUI_DB
- disable MTD_DOC2000 (wont build)
- build agp drivers as modules
- dropped a lot of patches (merged upstream):
  * CA09-CA11, CA13, CA15, CA17, CA19-CA24, CA27-CA28, CA35, CA37-CA40,
  * CA43-CA44, CB10, CC01, CI01, CM04-CM09, CS01, DA04, DA11-DA12, 
  * DA16, DA18, DA21-DA22, DB01-DB04, DB16-DB23, DF03, DI01-DI02,
  * DM01-DM02, DN01, DN05, DP01, DS01, DU01, DV13-DV14, FA01, FA03,
  * FA07, FA09, FE01-FE03, FQ01 
- dropped patches that needs verification:
  * CA08, CA12, CA14, CA33, CA36, CB11-CB12, DA15, DA20, 
  * DB05-DB06, DB08
- rediffed patches:
  * DS02, DV02
- replaced patches with newer ones:
  * DB09-DB14 replaced with DB21-DB27 (from mm1)
  * DA17 with DA37-DA38
- forcedeth 0.20
- pci.ids 20040109tmb
- supermount-ng 2.0.3a
- ieee1394 rev 1092
  * typos fixed, updated oui.db
- ext2 / ext3 fixes (from mm1)
  * inode fixes, debug fixes, next generation fixes
- libata sata_sil 0.52 updates (from mm1) 
  * support 3114, add another 3112 model (from mm1)
- add support for radeon Yd (from mm1)
- drm/dri 20040107 cvs (from mm1)
- NetGear FA311 mac byte swap address fix (from mm1)
- scsi fixes (from mm1)
  * inia100 fixes
  * qla1280 fixes
- misc fixes (from mm1)
  * rmmod race fix
  * rtc leak fix
  * vc init race fix
- nforce2 fixes for disconnect_quirk, io_apic edge (svetljo)
- alsa 1.0.1 (from mm1)
- alsa 1.0.1 addons (svetljo)
  * nforce 3 support
  * add sysfs class
  * aureal/vortex/vortex2
  * usx2y, pdplus, mixart, msnd, pdaudio, bt87x
  * echoaudio 0.8.3
- hpt374 autotune fix (svetljo)
- 3rparty drivers (svetljo)
  * bcm5700 7.1.9
  * bcm4400 3.0.7
  * qla2xxx-8.00.00b8
  * ivtv-281103cvs
  * hfsplus_20030930
  * viahss-0.92
  * ogfs
  * w9968cf-1.24
  * vt_ar5k-20030509
  * fuse-1.1_pre1
  * airo_mpi-20031220
  * svgalib_helper-1.9.18
- 3rdparty Makefile, Kconfig, misc fixes (svetljo)

* Thu Jan  1 2004 Thomas Backund <tmb@mandrake.org> 2.6.0-1.tmb.1mdk
- first kernel-tmb based on 2.6.0 final made by Nicholas
- squashfs 1.3r2
- pci.ids 2003-12-09 + my addons
- use some specfile and scripts magic from Juans 2.4.spec
- fix %postun macros
- merge changes from contrib kernel-2.6-2.6.0-1mdk
  * thanks to Oliver Blin and Oliver Thauvin for their great work
  * keep preemptive and cramfs buitin for now...
  * supermount 2.0.3

* Thu Dec 18 2003 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.0-1mdk
- 2.6.0 final version ;)
- ndis wrapper 0.3.
- fix uss725.

* Wed Dec 17 2003 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.0-0.5mdk
- bk13.
- acecad 1.3.
- uss725.
- bttv videodev i2c videobuf updates 20031216.
- dvb timeout fix.
- mod_marvel (Kevin O'Connor).
- matrox_fb fixes (Kevin O'Connor).
- forcedeth v19.
- kdb build fix.
- add siimage 3114 support.
- prism25 0.2.1-pre16.
- qc-usb cvs20031216.

* Fri Dec 12 2003 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.0-0.4mdk
- bk8.
- add vt|ar5k wireless chipset support.
- dos partition table consistency.
- warly touch boot logo ;)
- ndis wrapper 0.2. (only for up kernel)
- alsa 1.0.0rc2.
- agpgart and mousedev as built-in.

* Thu Dec 04 2003 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.0-0.3mdk
- bk1:
  * ide-scsi.c uninitialized variable
  * x86 kernel page fault error codes
  * lost wakeups problem
  * missing initialization of /proc/net/tcp seq_file
- rework merge version.h (now all kernel have UTS_RELEASE defined)
- 2.6.0-test11q2 :
  * libata update
  * pwc 8.12
  * prism54 cvs20031203
  * alsa 1.0.0rc1

* Fri Nov 28 2003 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.0-0.2mdk
- re-support on the fly module building (great for properitary packages)
- 2.6.0-test11q2 :
  * lots of mm patches
  * import somes 3rdparty and patches : (svetoslav)
    * lirc
    * at76c503a
    * bcm5700
    * dfg1394
    * dxr3
    * iscsi-mod
    * lufs
    * ov511
    * prism25
    * prism54
    * qc-usb

* Mon Nov 24 2003 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.0-0.1mdk
- First version to move on kernel-2.6.0. (aka: ready for a new age).
- 2.6.0-test10q1 :
  * only i386 config for the moment
  * bootsplash 3.1.3
  * mdk logo
  * forcedeth v18
  * adiusbadsl 1.0.4 (untested)
  * acx100 0.2.0pre6
  * hostap 0.1.2

# Local Variables:
# rpm-spec-insert-changelog-version-with-shell: t
# End:
